==> pyrotgfork-2.1.37-py3-none-any.whl: pyrogram/raw/types/stars_giveaway_winners_option.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class StarsGiveawayWinnersOption(TLObject):  # type: ignore
    """Allowed options for the number of giveaway winners.

    Constructor of :obj:`~pyrogram.raw.base.StarsGiveawayWinnersOption`.

    Details:
        - Layer: ``195``
        - ID: ``54236209``

    Parameters:
        users (``int`` ``32-bit``):
            The number of users that will be randomly chosen as winners.

        per_user_stars (``int`` ``64-bit``):
            The number of Telegram Stars each winner will receive.

        default (``bool``, *optional*):
            If set, this option must be pre-selected by default in the option list.

    """

    __slots__: List[str] = ["users", "per_user_stars", "default"]

    ID = 0x54236209
    QUALNAME = "types.StarsGiveawayWinnersOption"

    def __init__(self, *, users: int, per_user_stars: int, default: Optional[bool] = None) -> None:
        self.users = users  # int
        self.per_user_stars = per_user_stars  # long
        self.default = default  # flags.0?true

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "StarsGiveawayWinnersOption":
        
        flags = Int.read(b)
        
        default = True if flags & (1 << 0) else False
        users = Int.read(b)
        
        per_user_stars = Long.read(b)
        
        return StarsGiveawayWinnersOption(users=users, per_user_stars=per_user_stars, default=default)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.default else 0
        b.write(Int(flags))
        
        b.write(Int(self.users))
        
        b.write(Long(self.per_user_stars))
        
        return b.getvalue()

==> pyrotgfork-2.2.4-py3-none-any.whl: pyrogram/raw/types/stars_giveaway_winners_option.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class StarsGiveawayWinnersOption(TLObject):  # type: ignore
    """Allowed options for the number of giveaway winners.

    Constructor of :obj:`~pyrogram.raw.base.StarsGiveawayWinnersOption`.

    Details:
        - Layer: ``196``
        - ID: ``54236209``

    Parameters:
        users (``int`` ``32-bit``):
            The number of users that will be randomly chosen as winners.

        per_user_stars (``int`` ``64-bit``):
            The number of Telegram Stars each winner will receive.

        default (``bool``, *optional*):
            If set, this option must be pre-selected by default in the option list.

    """

    __slots__: list[str] = ["users", "per_user_stars", "default"]

    ID = 0x54236209
    QUALNAME = "types.StarsGiveawayWinnersOption"

    def __init__(self, *, users: int, per_user_stars: int, default: Optional[bool] = None) -> None:
        self.users = users  # int
        self.per_user_stars = per_user_stars  # long
        self.default = default  # flags.0?true

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "StarsGiveawayWinnersOption":
        
        flags = Int.read(b)
        
        default = True if flags & (1 << 0) else False
        users = Int.read(b)
        
        per_user_stars = Long.read(b)
        
        return StarsGiveawayWinnersOption(users=users, per_user_stars=per_user_stars, default=default)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.default else 0
        b.write(Int(flags))
        
        b.write(Int(self.users))
        
        b.write(Long(self.per_user_stars))
        
        return b.getvalue()
